@@ -110,12 +110,13 @@ class FXAS21002C:
     _BUFFER = bytearray(7)
 
     def __init__(self, i2c, address=_FXAS21002C_ADDRESS, gyro_range=GYRO_RANGE_250DPS):
-        assert gyro_range in (
+        if gyro_range not in (
             GYRO_RANGE_250DPS,
             GYRO_RANGE_500DPS,
             GYRO_RANGE_1000DPS,
             GYRO_RANGE_2000DPS,
-        )
+        ):
+            raise Exception("gyro_range option selected is not a valid option")
         self._gyro_range = gyro_range
         self._device = i2c_dev.I2CDevice(i2c, address)
         # Check for chip ID value.
